/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.activation.validators;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;
import se.vgregion.account.services.InvitePreferencesService;
import se.vgregion.create.domain.InvitePreferences;

import java.net.MalformedURLException;
import java.net.URL;

public class InvitePreferencesValidator implements Validator {

    @Autowired
    private InvitePreferencesService invitePreferencesService;

    @Override
    public boolean supports(Class<?> clazz) {
        return InvitePreferences.class.equals(clazz);
    }

    @Override
    public void validate(Object target, Errors errors) {
        //Check unique title
        InvitePreferences invitePreferences = (InvitePreferences) target;
        ValidationUtils.rejectIfEmptyOrWhitespace(errors, "title", "notnull.title", "Det måste finnas en titel");
        InvitePreferences persisted = invitePreferencesService.findByTitle(invitePreferences.getTitle());
        if (persisted != null
                && (invitePreferences.getId() == null || !invitePreferences.getId().equals(persisted.getId()))) {
            errors.rejectValue("title", "duplicate.title", "Titeln måste vara unik");
        }

        // invalid url
        try {
            new URL(invitePreferences.getCustomUrl());
        } catch (MalformedURLException e) {
            errors.rejectValue("customUrl", "invalid.url", "Felaktig url");
        }
    }

}
